/**
 * @file        API 路由总入口
 * @author      hotok
 * @date        2025-06-29
 * @lastEditor  hotok
 * @lastEditTime 2025-06-29
 * @description 所有 API 路由的统一入口，使用 group 进行模块化管理
 */

import { Elysia } from 'elysia';
import { healthController } from './health/health.controller';
import { userController } from './user/user.controller';
import { testController } from './test/test.controller';
import { exampleController } from './example/example.controller';

/**
 * 主路由控制器 - API 路由总入口
 * @description 统一管理所有 API 路由，便于维护和扩展
 */
export const controllers = new Elysia({
    prefix: '/api',
    name: 'controller',
})
    // 版本信息
    .get('/version', () => ({
        version: '1.0.0',
    }))
    // 用户系统接口
    .group('/user', (app) => app.use(userController))
    // 验证性接口
    .group('/test', (app) => app.use(testController))
    // 健康检查接口
    .group('/health', (app) => app.use(healthController))
    // 样例接口
    .group('/example', (app) => app.use(exampleController));
